summaryrefslogtreecommitdiff
path: root/lib/common/PartialReadStream.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/common/PartialReadStream.cpp')
-rw-r--r--lib/common/PartialReadStream.cpp12
1 files changed, 7 insertions, 5 deletions
diff --git a/lib/common/PartialReadStream.cpp b/lib/common/PartialReadStream.cpp
index 03cd3e50..c0508fd4 100644
--- a/lib/common/PartialReadStream.cpp
+++ b/lib/common/PartialReadStream.cpp
@@ -1,4 +1,4 @@
-// distribution boxbackup-0.10 (svn version: 494)
+// distribution boxbackup-0.11rc1 (svn version: 2023_2024)
//
// Copyright (c) 2003 - 2006
// Ben Summers and contributors. All rights reserved.
@@ -54,13 +54,15 @@
// --------------------------------------------------------------------------
//
// Function
// Name: PartialReadStream::PartialReadStream(IOStream &, int)
// Purpose: Constructor, taking another stream and the number of bytes
// to be read from it.
// Created: 2003/08/26
//
// --------------------------------------------------------------------------
-PartialReadStream::PartialReadStream(IOStream &rSource, int BytesToRead)
+PartialReadStream::PartialReadStream(IOStream &rSource,
+ pos_type BytesToRead)
: mrSource(rSource),
mBytesLeft(BytesToRead)
{
@@ -54,13 +54,15 @@
//
// Function
-// Name: PartialReadStream::PartialReadStream(IOStream &, int)
-// Purpose: Constructor, taking another stream and the number of bytes
-// to be read from it.
+// Name: PartialReadStream::PartialReadStream(IOStream &,
+// pos_type)
+// Purpose: Constructor, taking another stream and the number of
+// bytes to be read from it.
// Created: 2003/08/26
//